<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Push file updates.
 *
 * @package   tool_ally
 * @copyright Copyright (c) 2016 Blackboard Inc. (http://www.blackboard.com)
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace tool_ally;

use tool_ally\event\push_content_updates_error;

defined('MOODLE_INTERNAL') || die();

global $CFG;

require_once($CFG->libdir.'/filelib.php');

/**
 * Push file updates.
 *
 * @package   tool_ally
 * @copyright Copyright (c) 2018 Blackboard Inc. (http://www.blackboard.com)
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class push_content_updates extends push_updates{

    public function handle_send_error(\Exception $e) {
        // Too many errors, ensure it only runs on cli.
        set_config('push_cli_only', 1, 'tool_ally');
        // Log exception after max attempts.
        push_content_updates_error::create_from_exception($e)->trigger();
        // Log live push skip due to errors and switch to cli only.
        push_content_updates_error::create_from_msg(get_string('pushcontenterror:skip', 'tool_ally'))->trigger();
    }
}
