<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Tests for local library.
 *
 * @package   tool_ally
 * @copyright Copyright (c) 2016 Blackboard Inc. (http://www.blackboard.com)
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

use tool_ally\local;

defined('MOODLE_INTERNAL') || die();

/**
 * Tests for local library.
 *
 * @package   tool_ally
 * @copyright Copyright (c) 2016 Blackboard Inc. (http://www.blackboard.com)
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class tool_ally_local_testcase extends advanced_testcase {
    /**
     * Test get role IDs.
     */
    public function test_get_roleids() {
        global $DB;

        $this->resetAfterTest();

        $roles   = $DB->get_records_list('role', 'shortname', ['manager', 'coursecreator', 'editingteacher']);
        $roleids = local::get_roleids();
        foreach ($roles as $role) {
            $this->assertContains($role->id, $roleids);
            $this->assertArrayHasKey($role->id, $roleids);
        }

        set_config('roles', '', 'tool_ally');
        $this->assertEmpty(local::get_roleids());

        unset_config('roles', 'tool_ally');
        $this->assertEmpty(local::get_roleids());
    }

    /**
     * Test get admin IDs.
     */
    public function test_get_adminids() {
        $admins  = get_admins();
        $userids = local::get_roleids();
        foreach ($admins as $admin) {
            $this->assertContains($admin->id, $userids);
            $this->assertArrayHasKey($admin->id, $userids);
        }
    }
}